Command Line Tools
******************

.. contents::
   :local:

.. click:: datacube.scripts.cli_app:cli
   :prog: datacube
   :show-nested:

.. click:: datacube.scripts.search_tool:cli
   :prog: datacube-search
   :show-nested:

.. click:: datacube_apps.stacker:main
   :prog: datacube-stacker
   :show-nested:

.. click:: datacube.execution.worker:main
   :prog: datacube-worker
   :show-nested:

.. click:: datacube_apps.stacker:fixer_main
   :prog: datacube-fixer
   :show-nested:

.. click:: datacube_apps.ncml:ncml_app
   :prog: datacube-ncml
   :show-nested:
